<?php

/**
 * channels
 * @author Andchir <andchir@gmail.com>
 */

class channels extends cmsFrontend {
    
    /**
     * actionIndex
     *
     */
    public function actionIndex(){
        
        $template = cmsTemplate::getInstance();
        $user = cmsUser::getInstance();
        
        if( !$user->id ) { cmsCore::error404(); }
        
        return $this->actionUser( $user->id );
        
    }
    
    /**
     * actionUser
     *
     */
    public function actionUser( $user_id = 0 ){
        
        if( !$user_id ){ cmsCore::error404(); }
        
        $template = cmsTemplate::getInstance();
        $user = cmsUser::getInstance();
        
        $template->addCSS('templates/default/css/yt_channels-styles.css');
        
        if( $user->id ){
            $template->addToolButton(array(
                'class' => 'add',
                'title' => LANG_CHANNELS_ADD_TITLE,
                'href'  => href_to('channels', 'add')
            ));
        }
        
        $channels = $this->model->getChannels( $user_id );
        
        if( !$channels ){ $channels = array(); }
        
        return cmsTemplate::getInstance()->render('index', array(
            'channels' => $channels,
            'user_id' => $user_id
        ));
        
    }
    
    /**
     * actionAdd
     *
     */
    public function actionAdd( $user_id = 0 ){
        
        $template = cmsTemplate::getInstance();
        $user = cmsuser::getInstance();
        
        if( !$user_id ) { $user_id = $user->id; }
        if( !$user->id || ( !$user->is_admin && $user->id != $user_id ) ){ cmsCore::error404(); }
        
        //$form = $this->getItemForm();
        $form = $this->getForm('channel');
        
        $item = array();
        $errors = array();
        
        // Форма отправлена?
        $is_submitted = $this->request->has('submit');
        
        if ($is_submitted){
            
            // Парсим форму и получаем поля записи
            $item = array_merge($item, $form->parse($this->request, $is_submitted));
            
            $errors = $form->validate($this, $item);
            
            if ( $errors ){
                
                cmsUser::addSessionMessage(LANG_FORM_ERRORS, 'error');
                
            }else{
                
                $channel_data = $this->getChannelData( $item['name'] );
                
                if( !empty( $channel_data ) ){
                    
                    $item['name'] = $channel_data['name'];
                    $item['image_url'] = $channel_data['image_url'];
                    
                    if( empty( $item['title'] ) ){
                        $item['title'] = $channel_data['title'];
                    }
                    
                    if( empty( $item['description'] ) ){
                        $item['description'] = htmlspecialchars( $channel_data['description'] );
                    }
                    
                    $id = $this->model->addChannel( $item, $user_id );
                    
                    $this->redirectToAction('index');
                    
                }else{
                    cmsUser::addSessionMessage( LANG_CHANNELS_ERROR_CHANNEL_NO_EXISTS, 'error');
                }
                
            }
            
        }
        
        return cmsTemplate::getInstance()->render('add', array(
            'do' => 'add',
            'item' => $item,
            'errors' => $errors,
            'form' => $form
        ));
        
    }
    
    
    /**
     * actionEdit
     *
     */
    public function actionEdit( $channel_id ){
        
        $user = cmsuser::getInstance();
        
        if( !$user->id ){ cmsCore::error404(); }
        
        $item = $this->model->getChannel( $channel_id );
        
        if( !$item || ( !$user->is_admin && $item['user_id'] != $user->id ) ){ cmsCore::error404(); }
        
        $form = $this->getForm('channel');
        
        $errors = array();
        
        // Форма отправлена?
        $is_submitted = $this->request->has('submit');
        
        if ($is_submitted){
            
            $item = array_merge($item, $form->parse($this->request, $is_submitted, $item));
            
            $errors = $form->validate($this, $item);
            
            if ($errors){
                
                cmsUser::addSessionMessage(LANG_FORM_ERRORS, 'error');
                
            }else{
                
                $channel_data = $this->getChannelData( $item['name'] );
                
                if( !empty( $channel_data ) ){
                    
                    $item['name'] = $channel_data['name'];
                    $item['image_url'] = $channel_data['image_url'];
                    
                    if( empty( $item['title'] ) ){
                        $item['title'] = $channel_data['title'];
                    }
                    
                    if( empty( $item['description'] ) ){
                        $item['description'] = htmlspecialchars( $channel_data['description'] );
                    }
                    
                    $this->model->updateChannel( $channel_id, $item );
                    
                    $this->redirectToAction('index');
                    
                }else{
                    cmsUser::addSessionMessage( LANG_CHANNELS_ERROR_CHANNEL_NO_EXISTS, 'error');
                }
                
            }
            
        }
        
        return cmsTemplate::getInstance()->render('add', array(
            'do' => 'edit',
            'item' => $item,
            'errors' => $errors,
            'form' => $form
        ));
        
    }
    
    
    /**
     * actionRemove
     *
     */
    public function actionRemove( $channel_id = 0 )
    {
        
        $user = cmsuser::getInstance();
        
        if( !$user->id ){ cmsCore::error404(); }
        
        $channel = $this->model->getChannel( $channel_id );
        
        if( !$channel || ( !$user->is_admin && $channel['user_id'] != $user->id ) ){ cmsCore::error404(); }
        
        $this->model->removeChannel( $channel_id );
        
        $this->redirectToAction('index');
        
    }
    
    
    /**
     * getChannelData
     *
     */
    public function getChannelData( $channel_name ){
        
        $output = array();
        
        if( preg_match( "/(http:\/\/|https:\/\/)/", $channel_name ) ){
            
            preg_match( "/(?:channel|user)\/([^\/]+)/", $channel_name, $matches );
            
            if( $matches ){
                $channel_name = $matches[1];
            }else{
                $channel_name = '';
            }
            
        }
        
        if( !empty( $channel_name ) ){
            
            //http://www.youtube.com/channel/channelname/videos
            //http://gdata.youtube.com/feeds/api/users/channelname
            
            $xml_str = @file_get_contents( 'http://gdata.youtube.com/feeds/api/users/' . $channel_name );
            
            if( $xml_str ){
                
                $xml_str = str_replace( array('gd:','yt:','media:'), array('gd_','yt_','media_'), $xml_str );
                
                $xml_data = (array) simplexml_load_string( $xml_str );
                
                $output['name'] = !empty( $xml_data['yt_username'] ) ? $xml_data['yt_username'] : $channel_name;
                $output['image_url'] = !empty( $xml_data['media_thumbnail'] ) ? current( current( $xml_data['media_thumbnail'] ) ) : '';
                $output['title'] = !empty( $xml_data['title'] ) ? htmlspecialchars( trim( $xml_data['title'] ) ) : '';
                $output['description'] = !empty( $xml_data['content'] ) ? htmlspecialchars( trim( $xml_data['content'] ) ) : '';
                
            }
            
        }
        
        return $output;
        
    }
    
    
}

